// lib/dynamic-form-markdown.service.mjs
import { Injectable, SecurityContext } from "@angular/core";
import { marked } from "marked";
import { from, of } from "rxjs";
import { map, switchMap } from "rxjs/operators";
import * as i0 from "@angular/core";
import * as i1 from "@angular/common/http";
import * as i2 from "@angular/platform-browser";
var MarkdownRenderer = class extends marked.Renderer {
  link(href, title, text) {
    const link = super.link(href, title, text);
    return link.replace("<a", '<a target="_blank"');
  }
};
var DynamicFormMarkdownService = class _DynamicFormMarkdownService {
  constructor(httpClient, sanitizer) {
    this.httpClient = httpClient;
    this.sanitizer = sanitizer;
    marked.setOptions({ renderer: new MarkdownRenderer() });
  }
  compile(markdown, options) {
    const securityContext = this.getSecurityContext(options);
    return this.parseMarkdown(markdown).pipe(map((m) => this.sanitizer.sanitize(securityContext, m)));
  }
  compileFromSource(source, options) {
    return this.httpClient.get(source, { responseType: "text" }).pipe(switchMap((markdown) => this.compile(markdown, options)));
  }
  parseMarkdown(markdown) {
    const parsedMarkdown = marked.parse(markdown);
    return typeof parsedMarkdown === "string" ? of(parsedMarkdown) : from(parsedMarkdown);
  }
  getSecurityContext(options) {
    return options && !options.sanitize ? SecurityContext.NONE : SecurityContext.HTML;
  }
  static {
    this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i0, type: _DynamicFormMarkdownService, deps: [{ token: i1.HttpClient }, { token: i2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Injectable });
  }
  static {
    this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i0, type: _DynamicFormMarkdownService });
  }
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i0, type: DynamicFormMarkdownService, decorators: [{
  type: Injectable
}], ctorParameters: () => [{ type: i1.HttpClient }, { type: i2.DomSanitizer }] });

// lib/dynamic-form-markdown.component.mjs
import { AsyncPipe, NgClass } from "@angular/common";
import { Component } from "@angular/core";
import { DynamicFormElementBase } from "@dynamic-forms/core";
import { BehaviorSubject } from "rxjs";
import { switchMap as switchMap2 } from "rxjs/operators";
import * as i02 from "@angular/core";
var DynamicFormMarkdownComponent = class _DynamicFormMarkdownComponent extends DynamicFormElementBase {
  constructor(markdownService) {
    super();
    this.markdownService = markdownService;
  }
  ngOnInit() {
    this._markdownSubject = new BehaviorSubject({
      source: this.template.source,
      markdown: this.template.markdown
    });
    this.markdown$ = this._markdownSubject.asObservable().pipe(switchMap2((value) => value.source ? this.markdownService.compileFromSource(value.source, this.definition.options) : this.markdownService.compile(value.markdown, this.definition.options)));
  }
  ngDoCheck() {
    const source = this.template.source;
    const markdown = this.template.markdown;
    if (this._markdownSubject.value.source !== source || this._markdownSubject.value.markdown !== markdown) {
      this._markdownSubject.next({ source, markdown });
    }
  }
  static {
    this.ɵfac = i02.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i02, type: _DynamicFormMarkdownComponent, deps: [{ token: DynamicFormMarkdownService }], target: i02.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i02.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _DynamicFormMarkdownComponent, isStandalone: true, selector: "dynamic-form-markdown", usesInheritance: true, ngImport: i02, template: '<div class="dynamic-form-markdown" [ngClass]="template.className" [hidden]="hidden" [innerHTML]="markdown$ | async"></div>\n', dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
  }
};
i02.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i02, type: DynamicFormMarkdownComponent, decorators: [{
  type: Component,
  args: [{ standalone: true, selector: "dynamic-form-markdown", imports: [AsyncPipe, NgClass], template: '<div class="dynamic-form-markdown" [ngClass]="template.className" [hidden]="hidden" [innerHTML]="markdown$ | async"></div>\n' }]
}], ctorParameters: () => [{ type: DynamicFormMarkdownService }] });

// lib/dynamic-form-markdown.module.mjs
import { NgModule } from "@angular/core";
import { DynamicFormConfigModule, dynamicFormLibrary, importDynamicFormsProviders, withDynamicFormElements } from "@dynamic-forms/core";
import * as i03 from "@angular/core";
var dynamicFormMarkdownType = {
  type: "markdown",
  component: DynamicFormMarkdownComponent,
  libraryName: dynamicFormLibrary.name
};
function withDynamicFormsMarkdownFeatures() {
  const providers = [DynamicFormMarkdownService];
  return [{ providers }, withDynamicFormElements(dynamicFormMarkdownType)];
}
function provideDynamicFormsMarkdown() {
  return importDynamicFormsProviders(...withDynamicFormsMarkdownFeatures());
}
var modules = [DynamicFormConfigModule];
var DynamicFormMarkdownModule = class _DynamicFormMarkdownModule {
  static {
    this.ɵfac = i03.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i03, type: _DynamicFormMarkdownModule, deps: [], target: i03.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i03.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i03, type: _DynamicFormMarkdownModule, imports: [DynamicFormConfigModule], exports: [DynamicFormConfigModule] });
  }
  static {
    this.ɵinj = i03.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i03, type: _DynamicFormMarkdownModule, providers: provideDynamicFormsMarkdown(), imports: [modules, DynamicFormConfigModule] });
  }
};
i03.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i03, type: DynamicFormMarkdownModule, decorators: [{
  type: NgModule,
  args: [{
    imports: modules,
    exports: modules,
    providers: provideDynamicFormsMarkdown()
  }]
}] });
export {
  DynamicFormMarkdownComponent,
  DynamicFormMarkdownModule,
  DynamicFormMarkdownService,
  MarkdownRenderer,
  dynamicFormMarkdownType,
  provideDynamicFormsMarkdown,
  withDynamicFormsMarkdownFeatures
};
//# sourceMappingURL=dynamic-forms-markdown.mjs.map
